pub struct SessionDomain(/* private fields */);Expand description
Stable isolation boundary for one equivalent set of rustls server configs.
Transport family, authentication policy, and any compatibility epoch must be reflected in this value. Public TLS and mTLS must not share a domain.
Implementations